@@ -5,6 +5,6 @@ describe 'translate' do
   it { is_expected.to run.with_params('test string') }
   it { is_expected.to run.with_params(123).and_raise_error(ArgumentError) }
   it { is_expected.to run.with_params('test string', 123).and_raise_error(ArgumentError) }
-  it { is_expected.to run.with_params('test %{interpolate_this}', {'interpolate_this' => 'ok'}).and_return('test ok') }
+  it { is_expected.to run.with_params('test %{interpolate_this}', 'interpolate_this' => 'ok').and_return('test ok') }
   it { is_expected.to run.and_raise_error(ArgumentError) }
 end
